<p align="center">
  <img src="https://i.imgur.com/K3xz0Gf.png" width="600">
   <b>
    <center> <h1>insight-cv: A toolkit for scientific image analysis</h1> </center>
   </b>
</p>

## Mission statement 
`insight-cv` aims to be a well-documented and generalisable python framework for applying computer vision methods to a wide range of scientific imagery.

This tool aims to foster collaboration between **data owners** and **developers** by:
* Empowering scientific domain experts to easily access and integrate the latest CV tools
* Enabling algorithm developers to distribute their tools to users across scientific fields
* Evolving with a focus on the needs and priorities of both developers and users
* Creating and maintaining a community of interdisciplinary contributors
* Providing a bridge between different data scales and formats
